==> dde-shell_1.99.6.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>Àrea de connectors</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleccioneu quines icones apareixen a l&apos;acoblador.</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>Escriptori i barra de tasques</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>Establiu la visualització i la mida de les icones a l&apos;escriptori.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>Acoblador</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Fashion</source>
        <translation>Moda</translation>
    </message>
    <message>
        <source>Efficient-left</source>
        <translation>Eficient a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Efficient-center</source>
        <translation>Eficient al mig</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>Mida de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petita</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grossa</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>Posició a la pantalla</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Mantén-lo visible</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Mantén-lo amagat</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Pantalles múltiples</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>Establiu la posició de la barra de tasques a la pantalla.</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>Només a la principal</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>A la pantalla on hi ha el cursor</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Àrea de connectors</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleccioneu quines icones apareixen a l&apos;acoblador.</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.7.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>Àrea de connectors</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleccioneu quines icones apareixen a l&apos;acoblador.</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>Escriptori i barra de tasques</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>Establiu la visualització i la mida de les icones a l&apos;escriptori.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>Acoblador</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>Mida de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petita</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grossa</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>Posició a la pantalla</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Mantén-lo visible</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Mantén-lo amagat</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Pantalles múltiples</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>Establiu la posició de la barra de tasques a la pantalla.</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>Només a la principal</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>A la pantalla on hi ha el cursor</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Àrea de connectors</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleccioneu quines icones apareixen a l&apos;acoblador.</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
